unit DragObjectDemo;

interface

uses
  Classes, Controls, frxClass, Graphics, frxTableView;

type
  TDragObjectView = class(TfrxContainerView)
  private
    function CanDragObject(X, Y: Integer): Boolean;
  protected
    function StartDragObject(X, Y: Integer): Boolean; override;
    function GetCursor(X, Y: Integer): TCursor; override;
  public
    procedure Draw(Canvas: TCanvas; ScaleX, ScaleY, OffsetX, OffsetY: Extended); override;
    class function GetDescription: String; override;
  published
    property StretchMode;

    property BrushStyle;
    property Color;
    property DataField;
    property DataSet;
    property DataSetName;
    property Font;
    property Frame;
    property ParentFont;
  end;

implementation

uses frxDsgnIntf, Math, Forms;

{ TDragObjectView }

class function TDragObjectView.GetDescription: String;
begin
  Result := 'Drag demo component';
end;

procedure TDragObjectView.Draw(Canvas: TCanvas; ScaleX, ScaleY, OffsetX,
  OffsetY: Extended);
var
  X, Y: Integer;
begin
  BeginDraw(Canvas, ScaleX, ScaleY, OffsetX, OffsetY);
  DrawBackground;

  Canvas.Brush.Style := bsClear;

  Canvas.Pen.Style := psSolid;
  Canvas.Pen.Width := 2;
  Canvas.Pen.Color := Frame.Color;
  Canvas.Rectangle(FX, FY, FX1+1, FY1+1);

  if MousePressed then
  begin
    Canvas.Pen.Style := psDash;
    Canvas.Pen.Width := 1;
    X := Min(Max(CurrentMouseX, Round(FX)), Round(FX1));
    Y := Min(Max(CurrentMouseY, Round(FY)), Round(FY1));
    FCanvas.MoveTo(FX, Y);
    FCanvas.LineTo(FX1, Y);
    FCanvas.MoveTo(X, FY);
    FCanvas.LineTo(X, FY1);
  end;

  DrawFrame;
end;

function TDragObjectView.StartDragObject(X, Y: Integer): Boolean;
begin
  Result := CanDragObject(X, Y);
end;

function TDragObjectView.CanDragObject(X, Y: Integer): Boolean;
begin
  Result := X > Left + Width / 2;
end;

function TDragObjectView.GetCursor(X, Y: Integer): TCursor;
begin
  Result := inherited GetCursor(X, Y);
  if CanDragObject(X, Y) then Result := crHand
end;

end.
